import numpy
import xarray
import matplotlib.pyplot as plt
from configparser import ConfigParser

file = 'lazyearth.ini'
config = ConfigParser()
config.read(file)

class objearth():
    def __init__(self,DataArray):
        self.DataArray = DataArray

    def plotshow(self,lst=True):
        self.lst = lst
        if type(self.DataArray) == xarray.core.dataarray.DataArray:
            if self.lst==True:
                ymax = 0 ; ymin = self.DataArray.shape[0]
                xmin = 0 ; xmax = self.DataArray.shape[1] 
            else:
                ymax = self.lst[0] ; ymin = self.lst[1]
                xmin = self.lst[2] ; xmax = self.lst[3]
            lon  =  self.DataArray.longitude.to_numpy()[xmin:xmax]
            lon0 =  lon[0] ; lon1 =  lon[-1]
            lat  =  self.DataArray.latitude.to_numpy()[ymax:ymin]
            lat0 = -lat[-1] ; lat1 = -lat[0]
            def longitude(lon):
                return [lon0,lon1]
            def latitude(lat):
                return [lat0,lat1]
            def axis(x=0):
                return x
            fig,ax = plt.subplots(constrained_layout=True)
            fig.set_size_inches(7,7)
            ax.set_xlabel('x axis size')
            ax.set_ylabel('y axis size')
            ax.imshow(self.DataArray[ymax:ymin,xmin:xmax],extent=[xmin,xmax,ymin,ymax])
            secax_x = ax.secondary_xaxis('top',functions=(longitude,axis))
            secax_x.set_xlabel('longitude')
            secax_x = ax.secondary_xaxis('top',functions=(longitude,axis))
            secax_x.set_xlabel('longitude')
            secax_y = ax.secondary_yaxis('right',functions=(latitude,axis))
            secax_y.set_ylabel('latitute')
            plt.grid(color='w', linestyle='-', linewidth=0.1)
            plt.show()
        
        elif type(self.DataArray) == numpy.ndarray:
            if self.lst==True:
                ymax = 0 ; ymin = self.DataArray.shape[0]
                xmin = 0 ; xmax = self.DataArray.shape[1]
            else:
                ymax = self.lst[0] ; ymin = self.lst[1]
                xmin = self.lst[2] ; xmax = self.lst[3]
            plt.figure(figsize=(10,10))
            plt.imshow(self.DataArray[ymax:ymin,xmin:xmax],extent=[xmin,xmax,ymin,ymax])
        
        else:
            print("Nonetype :",type(self.DataArray))
            
    def NDVI(self):
        Nodata = int(config['Data']['Nodata'])
        fractionconstant = float(config['Plot']['fractionnumber'])
        red = xarray.where(self.DataArray.red==Nodata,numpy.nan,self.DataArray.red)
        nir = xarray.where(self.DataArray.nir==Nodata,numpy.nan,self.DataArray.nir)
        ndvi1 = (nir-red)/(nir+red).to_numpy()
        ndvi3 = numpy.clip(ndvi1,-1,1)
        im_ratio = ndvi3.shape[1]/ndvi3.shape[0]
        plt.figure(figsize=(8,8))
        plt.xticks([]), plt.yticks([])
        plt.imshow(ndvi3,cmap='viridis')
        plt.clim(-1,1)
        plt.colorbar(orientation="vertical",fraction=fractionconstant*im_ratio)
        plt.show()
        return ndvi3

    def percentcloud(self,Dataset):
        Cloud = (config['Cloud']['Fashcloud'])
        self.Dataset = Dataset
        FashCloud = Cloud
        dstest    = self.Dataset.pixel_qa
        dsnew     = xarray.where(dstest == FashCloud[0],numpy.nan,dstest)
        dsnew     = xarray.where(dsnew  == FashCloud[1],numpy.nan,dsnew)
        dsnew     = xarray.where(dsnew  == FashCloud[2],numpy.nan,dsnew)
        Cpixel    = (numpy.isnan(dsnew.to_numpy())).sum()
        Allpixel  = int(self.Dataset.pixel_qa.count())
        Cloudpercent = (Cpixel/Allpixel)*100
        print("Percent Cloud : %.4f"%Cloudpercent,"%")
   
    




import io
from os.path import abspath, dirname, join
from setuptools import find_packages, setup


HERE = dirname(abspath(__file__))
LOAD_TEXT = lambda name: io.open(join(HERE, name), encoding='UTF-8').read()
DESCRIPTION = '\n\n'.join(LOAD_TEXT(_) for _ in [
    'README.rst'
])

setup(
  name = 'lazyearth',                # Name project the same with folder
  packages = ['lazyearth'],          # Name project the same with folder
  version = '0.0.18',                 # 
  license='MIT', 
  description = 'Library OOP for workwith odc by Tun Kedsaro',    #Show on PyPi
  long_description=DESCRIPTION,
  author = 'Tun Kedsaro',            #          
  author_email = 'Tun.k@ku.th',      #
  url = 'https://github.com/Tun555/lazyearth',  #
  download_url = 'https://github.com/Tun555/lazyearth/archive/refs/tags/v0.0.15.zip',                                      #  
  keywords = ['OOP','ODC'],      # When someone search
  install_requires=[                 # Package that use
        'numpy',
        'matplotlib',
    ],  
  classifiers=[    
    'Development Status :: 1 - Planning',  
    'Intended Audience :: Education', 
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Version pathon that we test    
    'Programming Language :: Python :: 3.8',
  ],
)


# from lazyearth.mainfile import objearth

from configparser import ConfigParser

file = 'lazyearth.ini'
config = ConfigParser()
config.read(file)

fractionconstant = float(config['Plot']['fractionnumber'])
print(fractionconstant)

Nodata = int(config['Data']['Nodata'])
print(Nodata)

Cloud = (config['Cloud']['Fashcloud'])
print(Cloud)
